@@ -18,7 +18,20 @@ set -o errexit
 set -o nounset
 set -o pipefail
 
-source $(dirname $0)/../vendor/knative.dev/hack/library.sh
+source $(dirname $0)/../vendor/knative.dev/hack/codegen-library.sh
+
+group "Deepcopy Gen"
+
+# Broken out of code-generator scripts, since we don't need generate-groups.sh
+(
+    cd "${CODEGEN_PKG}"
+    go install ./cmd/deepcopy-gen
+)
+
+${GOPATH}/bin/deepcopy-gen \
+  -O zz_generated.deepcopy \
+  --go-header-file "${REPO_ROOT_DIR}/hack/boilerplate/boilerplate.go.txt" \
+  -i knative.dev/net-kourier/pkg/config
 
 # Make sure our dependencies are up-to-date
 ${REPO_ROOT_DIR}/hack/update-deps.sh
